0.9.9 API documentation: vector_double2.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_double2.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec2.hpp"
6
7 namespace glm
8 {
11
15 typedef vec<2, double, defaultp> dvec2;
16
18 }//namespace glm
glm::dvec2
vec< 2, double, defaultp > dvec2
2 components vector of double-precision floating-point numbers.
Definition: vector_double2.hpp:15
glm
Definition: common.hpp:20